@@ -4,7 +4,7 @@ from __future__ import with_statement
 from distutils.dir_util import copy_tree
 from optparse import OptionParser
 import os
-from shutil import move
+from shutil import move, rmtree
 from uuid import uuid4
 
 from mezzanine.utils.importing import path_for_import
@@ -12,8 +12,8 @@ from mezzanine.utils.importing import path_for_import
 
 def create_project():
     """
-    Copies the contents of the project_template directory to a new directory
-    specified as an argument to the command line.
+    Copies the contents of the project_template directory to a new
+    directory specified as an argument to the command line.
     """
 
     parser = OptionParser(usage="usage: %prog [options] project_name")
@@ -32,8 +32,8 @@ def create_project():
         parser.error("project_name cannot start with '-'")
     project_path = os.path.join(os.getcwd(), project_name)
 
-    # Ensure the given directory name doesn't clash with an existing Python
-    # package/module.
+    # Ensure the given directory name doesn't clash with an existing
+    # Python package/module.
     try:
         __import__(project_name)
     except ImportError:
@@ -43,8 +43,9 @@ def create_project():
             "Python module and cannot be used as a project name. "
             "Please try another name." % project_name)
 
-    # Create the list of packages to build from - at this stage it should
-    # only be one or two names, mezzanine plus an alternate package.
+    # Create the list of packages to build from - at this stage it
+    # should only be one or two names, mezzanine plus an alternate
+    # package.
     packages = ["mezzanine"]
     if options.alt:
         packages.append(options.alt)
@@ -54,8 +55,9 @@ def create_project():
         except ImportError:
             parser.error("Could not import package '%s'" % package_name)
 
-    # Build the project up copying over the project_template from each of
-    # the packages.
+    # Build the project up copying over the project_template from
+    # each of the packages.
+    template_path = os.path.join(project_path, "templates")
     for package_name in packages:
         package_path = path_for_import(package_name)
         if options.copy_source:
@@ -64,11 +66,17 @@ def create_project():
         move(os.path.join(project_path, "local_settings.py.template"),
             os.path.join(project_path, "local_settings.py"))
         if options.copy_templates:
-            template_path = os.path.join(project_path, "templates")
             for app_dir in os.listdir(package_path):
                 template_dir = os.path.join(package_path, app_dir, "templates")
                 if os.path.isdir(template_dir):
                     copy_tree(template_dir, template_path)
+    # Remove admin templates from the project to allow for easier
+    # upgrading, as these templates need not be customised.
+    if options.copy_templates:
+        try:
+            rmtree(os.path.join(template_path, "admin"))
+        except OSError:
+            pass
 
     # Generate a unique SECREY_KEY for the project's setttings module.
     settings_path = os.path.join(os.getcwd(), project_name, "settings.py")
