@@ -69,7 +69,7 @@ class PageAdmin(DisplayableAdmin):
                 return HttpResponseRedirect(change_url)
         extra_context = extra_context or {}
         extra_context["hide_delete_link"] = not page.can_delete(request)
-        extra_context["hide_slug_field"] = not page.overridden()
+        extra_context["hide_slug_field"] = page.overridden()
         return super(PageAdmin, self).change_view(request, object_id,
                                                   extra_context)
 
